@@ -4,9 +4,14 @@
 module Test.QuickCheck.Instances.Hashable () where
 
 import Prelude ()
-import Prelude.Compat
+import Test.QuickCheck.Instances.CustomPrelude
 
 import Data.Hashable (Hashable, Hashed, hashed)
+#if MIN_VERSION_hashable(1,4,0)
+import Data.Hashable (hashedHash)
+#else
+import Data.Hashable (hash)
+#endif
 
 import Test.QuickCheck
 
@@ -19,5 +24,9 @@ instance (Hashable a, Arbitrary a) => Arbitrary (Hashed a) where
     arbitrary = hashed <$> arbitrary
 
 instance CoArbitrary (Hashed a) where
-    coarbitrary x = coarbitrary (hashed x)
+#if MIN_VERSION_hashable(1,4,0)
+    coarbitrary x = coarbitrary (hashedHash x :: Int)
+#else
+    coarbitrary x = coarbitrary (hash x :: Int)
+#endif
 #endif
