@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 module Main (main) where
 
 import Data.Proxy (Proxy (..))
@@ -6,8 +7,13 @@ import Test.QuickCheck.Instances ()
 
 import qualified Data.Tree as Tree
 import qualified Data.Primitive as Prim
+
 import           Data.UUID.Types (UUID)
 
+#if MIN_VERSION_base(4,9,0)
+import qualified Data.Array.Byte as AB
+#endif
+
 -- | Example law: == (and thus ===) should be reflexive.
 eqReflexive
     :: (Eq a, Show a)
@@ -22,3 +28,6 @@ main = do
     quickCheck $ eqReflexive (Proxy :: Proxy (Tree.Tree Int))
     quickCheck $ eqReflexive (Proxy :: Proxy UUID)
     quickCheck $ eqReflexive (Proxy :: Proxy Prim.ByteArray)
+#if MIN_VERSION_base(4,9,0)
+    quickCheck $ eqReflexive (Proxy :: Proxy AB.ByteArray)
+#endif
